chatter.migrations package
==========================

Submodules
----------

chatter.migrations.0001\_initial module
---------------------------------------

.. automodule:: chatter.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:

chatter.migrations.0002\_auto\_20200922\_1209 module
----------------------------------------------------

.. automodule:: chatter.migrations.0002_auto_20200922_1209
   :members:
   :undoc-members:
   :show-inheritance:

chatter.migrations.0003\_auto\_20200922\_1221 module
----------------------------------------------------

.. automodule:: chatter.migrations.0003_auto_20200922_1221
   :members:
   :undoc-members:
   :show-inheritance:

chatter.migrations.0004\_auto\_20200925\_1757 module
----------------------------------------------------

.. automodule:: chatter.migrations.0004_auto_20200925_1757
   :members:
   :undoc-members:
   :show-inheritance:

chatter.migrations.0005\_auto\_20200925\_1856 module
----------------------------------------------------

.. automodule:: chatter.migrations.0005_auto_20200925_1856
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: chatter.migrations
   :members:
   :undoc-members:
   :show-inheritance:
